Index: include.preload.js |
=================================================================== |
--- a/include.preload.js |
+++ b/include.preload.js |
@@ -26,9 +26,10 @@ |
var style = document.createElement("style"); |
style.setAttribute("type", "text/css"); |
- // Use Shadow DOM if available to don't mess with web pages |
- // that rely on the order of their own <style> tags (#309) |
- if ("webkitCreateShadowRoot" in document.documentElement) |
+ // Use Shadow DOM if available to don't mess with web pages that |
+ // rely on the order of their own <style> tags. However the |
+ // <shadow> element is broken in Chrome Chrome 32.0.1700 (#309) |
Thomas Greiner
2014/04/17 12:24:17
"in Chrome Chrome" ;)
Sebastian Noack
2014/04/17 12:30:32
Done.
|
+ if ("webkitCreateShadowRoot" in document.documentElement && !/\bChrome\/32\.0\.1700\b/.test(navigator.userAgent)) |
Felix Dahlke
2014/04/17 12:05:38
Is there no other way to figure out if the shadow
Sebastian Noack
2014/04/17 12:24:17
Please see the discussion at https://issues.adbloc
Thomas Greiner
2014/04/17 12:24:17
In what way is it broken? You mention that the "<s
Sebastian Noack
2014/04/17 12:30:32
Same effect as if it wouldn't be there. And since
|
{ |
var shadow = document.documentElement.webkitCreateShadowRoot(); |
shadow.appendChild(document.createElement("shadow")); |